Summary: Exclude openshift packages from updates
Name: openshift-excluder
Version: 1.0
Release: 0.6
License: ASL 2.0
URL: http://www.fnal.gov/cd/UNIX/linux/
BuildArch: noarch

%description
Many times admins do not want openshift updated when doing
normal system updates.

%{name} exclude - No openshift packages will be updated
%{name} unexclude - Openshift packages will be updated

%install
rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT/usr/sbin
%if 0%{?fedora}
  OS_CONF_FILE="/etc/dnf.conf"
%else
  OS_CONF_FILE="/etc/yum.conf"
%endif
OS_NAME="origin"

cat <<EOF > $RPM_BUILD_ROOT/usr/sbin/%{name}
#!/bin/bash
#
# This script will either enable, or disable, the updating 
#  of openshift rpms via yum
#
##############
# VARIABLES
##############
CONF_FILE="${OS_CONF_FILE}"
PACKAGE_LIST="${OS_NAME} ${OS_NAME}-clients ${OS_NAME}-clients-redistributable ${OS_NAME}-dockerregistry ${OS_NAME}-master origin-node ${OS_NAME}-pod origin-recycle ${OS_NAME}-sdn-ovs ${OS_NAME}-tests tuned-profiles-${OS_NAME}-node"

##############
# HELP
##############
usage() {
  echo "Usage: \${0} <exclude | unexclude>" >&2
  echo >&2
  echo "exclude | disable" >&2                                                                                         
  echo "  exclude all openshift packages via an excludes= line in \${CONF_FILE}" >&2                                    
  echo "  This disables updates for all openshift packages" >&2
  echo >&2
  echo "unexclude | enable" >&2
  echo "  removes all openshift packages from the excludes= line in \${CONF_FILE}" >&2
  echo "  This re-enables updates for all openshift packages" >&2
  echo >&2
  popd &>/dev/null
  exit 1
}

##############
# FUNCTIONS
##############
exclude_packages() {
  # Ensure there is an exclude line
  if ! grep -q exclude= \${CONF_FILE} ; then
    echo "Adding exclude= to \${CONF_FILE}"
    sed 's|\(obsoletes=.*\)|\1\nexcludes=|' \${CONF_FILE}
  fi
  # Add each package to the exclude line
  for package in \${PACKAGE_LIST}
  do
    if ! grep exclude= /etc/yum.conf | grep -q " \${package} " ; then
      sed -i "s|exclude=|exclude= \${package} |" \${CONF_FILE}
    fi
  done
}

unexclude_packages() {
  # Remove each package to the exclude line
  for package in \${PACKAGE_LIST}
  do
    if grep exclude= /etc/yum.conf | grep -q " \${package} " ; then
      sed -i "s| \${package} ||" \${CONF_FILE}
    fi
  done
}

##############
# MAIN PROGRAM
##############
case "\$1" in
  exclude | disable )
    exclude_packages
    ;;
  unexclude | enable )
    unexclude_packages
    ;;
  * )
    echo "Unknown Option: \${1}"
    echo
    usage
    ;;
esac

exit 0
EOF

chmod 744 $RPM_BUILD_ROOT/usr/sbin/%{name}

%post
if [ "$1" -eq 1 ] ; then
  openshift-excluder exclude
fi

%preun
if [ "$1" -eq 0 ] ; then
  /usr/sbin/openshift-excluder unexclude
fi


%files
/usr/sbin/%{name}

%changelog
* Mon Sep 12 2016 Troy Dawson <dawson@fnal.gov> 1.0-0.6
- Use OS_NAME in package list, easier to switch between origin and ose

* Wed Sep 07 2016 Troy Dawson <dawson@fnal.gov> 1.0-0.5
- Initial rpm build

